summaryrefslogtreecommitdiffstats
path: root/server/src/com
diff options
context:
space:
mode:
Diffstat (limited to 'server/src/com')
-rw-r--r--server/src/com/vaadin/ui/declarative/Design.java (renamed from server/src/com/vaadin/ui/declarative/LayoutHandler.java)10
1 files changed, 5 insertions, 5 deletions
diff --git a/server/src/com/vaadin/ui/declarative/LayoutHandler.java b/server/src/com/vaadin/ui/declarative/Design.java
index b3ef2f15c7..89e992181b 100644
--- a/server/src/com/vaadin/ui/declarative/LayoutHandler.java
+++ b/server/src/com/vaadin/ui/declarative/Design.java
@@ -35,16 +35,16 @@ import com.vaadin.ui.declarative.DesignContext.ComponentCreatedEvent;
import com.vaadin.ui.declarative.DesignContext.ComponentCreationListener;
/**
* LayoutHandler is used for parsing a component hierarchy from an html file
* and, conversely, for generating an html tree representation corresponding to
* a given component hierarchy. For both parsing and tree generation the
* component hierarchy must contain a single root.
*
*
* @since 7.4
* @author Vaadin Ltd
*/
-public class LayoutHandler implements Serializable {
+public class Design implements Serializable {
/**
* Constructs a component hierarchy from the design specified as an html
* document. The component hierarchy must contain exactly one top-level
@@ -35,16 +35,16 @@ import com.vaadin.ui.declarative.DesignContext.ComponentCreatedEvent;
import com.vaadin.ui.declarative.DesignContext.ComponentCreationListener;
/**
- * LayoutHandler is used for parsing a component hierarchy from an html file
- * and, conversely, for generating an html tree representation corresponding to
- * a given component hierarchy. For both parsing and tree generation the
- * component hierarchy must contain a single root.
+ * Design is used for parsing a component hierarchy from an html file and,
+ * conversely, for generating an html tree representation corresponding to a
+ * given component hierarchy. For both parsing and tree generation the component
+ * hierarchy must contain a single root.
*
*